@@ -12,8 +12,12 @@ def validate_url(ctx, param, value):
 
 
 def update_config_file(data):
-    with open(settings.PATH_TO_MS_CONFIG, 'w') as outfile:
-        json.dump(data, outfile)
+    try:
+        with open(settings.PATH_TO_MS_CONFIG, 'w+') as outfile:
+            json.dump(data, outfile)
+    except FileNotFoundError:
+        with open(settings.PATH_TO_MS_CONFIG, 'w') as outfile:
+            print(outfile, data)
 
 
 @click.command()
